@@ -150,8 +150,40 @@ class LPObject:
         else:
             self.eq_lst.append(Eq(var_lst,sense,b,description))
     
+    def add_switch(self,switch:LPStateVar,var1:LPStateVar,var2:LPStateVar,description='',big_M=1e6):
+        """
+        Adds equations that implement a switch between two state variables so that only one of the two variables can ever be unequal to 0. 
+        Works for both timedependent and additional variables.
+        The binary switch variable has to be implemented manually in the init.
+        The switch variable takes the value 1 if var1 is active and 0 if var2 is active.
+        ! If the boundaries are infinite, the boundaries will be set to -big_M and big_M instead.
+        """
+        self.description = description
+        if switch.vtype is not 'B':
+            raise ValueError('Switch variable has to be binary')
+        if not isinstance(var1,LPStateVar) or not isinstance(var2,LPStateVar):
+            raise ValueError('The variables have to be state variables')
+        
+        var1_lb = var1.lb if np.isfinite(var1.lb) else -big_M
+        var1_ub = var1.ub if np.isfinite(var1.ub) else big_M
+        var2_lb = var2.lb if np.isfinite(var2.lb) else -big_M
+        var2_ub = var2.ub if np.isfinite(var2.ub) else big_M
+        
+        self.add_eq([[var1,1],
+                     [switch,-var1_ub]],
+                     '<',0)
+        self.add_eq([[var1,1],
+                     [switch,-var1_lb]],
+                     '>',0)
+        self.add_eq([[var2,1],
+                     [switch,var2_ub]],
+                     '<',var2_ub)
+        self.add_eq([[var2,1],
+                     [switch,var2_lb]],
+                     '>',var2_lb)
+    
     def getStateVars(self)->list[LPStateVar]:
-        '''greturns list of state_vars'''
+        '''returns list of state_vars'''
         return self.stateVar_lst
                 
     def def_equations(self):
